from flask import Flask
from config import Config
from models import db
from flask_migrate import Migrate
from routes.users import users_bp
from routes.books import books_bp
from controller.auth import auth_bp
from routes.reader_progress import progress_bp
from controller.file_manipulation import file_manipulation_bp
from flask_cors import CORS

app = Flask(__name__)
app.secret_key = 'senha_super_secreta'

app.config.from_object(Config)

# Initialize CORS and allow only specific origin
CORS(app, origins=["https://vir.totalclan.com.br"], supports_credentials=True)

db.init_app(app)
migrate = Migrate(app, db)

# Register the Blueprints
app.register_blueprint(users_bp)
app.register_blueprint(auth_bp, url_prefix='/auth')
app.register_blueprint(books_bp, url_prefix='/books')
app.register_blueprint(file_manipulation_bp, url_prefix='/files')
app.register_blueprint(progress_bp, url_prefix='/progress')

if __name__ == '__main__':
    app.run()
