from flask import jsonify
from backend_flask.services.reader_progress import save_reader_progress_service
from backend_flask.services.reader_service import get_reader_id_by_user_id
from backend_flask.services.book_save_progress import check_if_book_exists, check_chapter_and_page

def save_progress_controller(data, user_id):
    reader_id = get_reader_id_by_user_id(user_id)

    required_fields = ['book_id', 'chapter_number', 'page_number']
    missing_fields = [field for field in required_fields if field not in data]

    if missing_fields:
        return jsonify({'error': 'Missing required fields', 'fields': missing_fields}), 400

    book_id = data['book_id']
    chapter_number = data['chapter_number']
    page_number = data['page_number']

    if not check_if_book_exists(book_id):
        return jsonify({'error': 'The book does not exist'}), 400

    if not check_chapter_and_page(book_id, chapter_number, page_number):
        return jsonify({'error': 'Incorrect chapter or page'}), 400

    try :
        save_reader_progress_service(reader_id, book_id, chapter_number, page_number)
        return jsonify({'status': 'success', 'message': 'Progress saved successfully'}), 201
    except Exception as e:
        return jsonify({'error': 'An error occurred while saving progress', 'message': str(e)}), 500
