from flask import jsonify

from models import Book
from services.upload_book import save_gifs_to_db, save_pdf, extract_and_save_chapters
from services.upload_book import save_cover, save_pdf_to_filesystem, save_book_to_db, save_file_to_db
from models import db

def upload_book_controller(category_id, title, author, description, published_at, cover, pdf, gifs, gif_descriptions):
    if not cover or not pdf:
        return jsonify({'error': 'Cover and PDF are required'}), 400

    try:
        cover_filename = save_cover(cover)


        existing_book = Book.query.filter_by(title=title, author=author).first()
        if existing_book:
            new_book = existing_book
        else:
            new_book = save_book_to_db(category_id, title, author, description, 0, published_at, cover_filename)

        pdf_filename = save_pdf(pdf, new_book.id)

        num_pages = extract_and_save_chapters(pdf_filename, new_book.id)

        new_book.total_pages = num_pages
        db.session.commit()

        if gifs:
            gif_data = zip(gifs, gif_descriptions)
            response, status_code = save_gifs_to_db(new_book.id, gif_data)
            if status_code != 201:
                return jsonify(response), status_code

        return jsonify({
            'status': 'success',
            'book_id': new_book.id
        }), 201

    except ValueError as e:
        return jsonify({'error': str(e)}), 400
    except Exception as e:
        return jsonify({'error': 'Error processing the upload.'}), 500

