from flask import Blueprint, request, jsonify
from controller.upload_books import upload_book_controller
from models import db, User, Book, ReaderProgress, Reader


books_bp = Blueprint('books', __name__)

@books_bp.route('/upload', methods=['POST'])
def upload_book():
    try:
        category_id = request.form['category_id']
        title = request.form['title']
        author = request.form['author']
        description = request.form['description']
        published_at = request.form['published_at']

        cover = request.files['cover']
        pdf = request.files['pdf']
        gifs = request.files.getlist('gifs')
        gif_descriptions = request.form.getlist('gif_descriptions')

        return upload_book_controller(category_id, title, author, description, published_at, cover, pdf, gifs, gif_descriptions)

    except KeyError as e:
        return jsonify({'error': f'Missing field: {str(e)}'}), 400
    except Exception as e:
        return jsonify({'error': str(e)}), 500

@books_bp.route('/', methods=['GET'])
def get_books():
    books = Book.query.all()

    return jsonify([{
        'id': book.id,
        'category_id': book.category_id,
        'title': book.title,
        'author': book.author,
        'description': book.description,
        'cover': book.cover,
        'total_pages': book.total_pages,
        'published_at': book.published_at
    } for book in books]), 200

@books_bp.route('/<int:book_id>', methods=['GET'])
def get_book_by_id(book_id):
    book = Book.query.get_or_404(book_id)

    return jsonify({
        'id': book.id,
        'category_id': book.category_id,
        'title': book.title,
        'author': book.author,
        'description': book.description,
        'cover': book.cover,
        'total_pages': book.total_pages,
        'published_at': book.published_at
    }), 200

#FALTA DELETAR TUDO QUE ESTÁ ASSOCIADO AO LIVRO, COMO A PROGRESS-BAR
@books_bp.route('/<int:book_id>', methods=['DELETE'])
def delete_book(book_id):
    book = Book.query.get_or_404(book_id)

    db.session.delete(book)
    db.session.commit()

    return jsonify({'message': 'Book deleted successfully!'}), 200

@books_bp.route('/user/<int:user_id>', methods=['GET'])
def get_all_books_by_user(user_id):
    try:
        books = db.session.query(Book, ReaderProgress) \
            .join(ReaderProgress, ReaderProgress.book_id == Book.id) \
            .filter(ReaderProgress.reader_id == user_id).all()

        if not books:
            return jsonify({'message': 'No books found for this user'}), 404

        return jsonify([{
            'id': book.id,
            'category_id': book.category_id,
            'category_name': book.category.name,
            'title': book.title,
            'author': book.author,
            'description': book.description,
            'cover': book.cover,
            'total_pages': book.total_pages,
            'published_at': book.published_at,
            'chapter_number': progress.chapter_number,
            'page_number': progress.page_number
        } for book, progress in books]), 200

    except Exception as e:
        return jsonify({'error': str(e)}), 500


@books_bp.route('/<int:book_id>/user/<int:user_id>', methods=['GET'])
def get_one_book_by_user(user_id, book_id):
    try:
        book_progress = db.session.query(Book, ReaderProgress) \
            .join(ReaderProgress, ReaderProgress.book_id == Book.id) \
            .filter(ReaderProgress.reader_id == user_id, Book.id == book_id).first()

        if not book_progress:
            return jsonify({'message': 'No book found for this user with the given ID'}), 404

        book, progress = book_progress

        return jsonify({
            'id': book.id,
            'category_id': book.category_id,
            'category_name': book.category.name,
            'title': book.title,
            'author': book.author,
            'description': book.description,
            'cover': book.cover,
            'total_pages': book.total_pages,
            'published_at': book.published_at,
            'chapter_number': progress.chapter_number,
            'page_number': progress.page_number
        }), 200

    except Exception as e:
        return jsonify({'error': str(e)}), 500


@books_bp.route('/<int:book_id>/user/<int:user_id>/start', methods=['POST'])
def associate_book_to_user(user_id, book_id):
    try:
        reader = Reader.query.filter_by(user_id=user_id).first()

        if not reader:
            reader = Reader(
                user_id=user_id,
                school_id=None,
                class_id=None
            )
            db.session.add(reader)
            db.session.commit()

        existing_progress = ReaderProgress.query.filter_by(reader_id=reader.id, book_id=book_id).first()

        if existing_progress:
            return jsonify({'message': 'Progress for this book and user already exists'}), 400

        new_progress = ReaderProgress(
            book_id=book_id,
            reader_id=reader.id,
            chapter_number=0,
            page_number=0
        )
        db.session.add(new_progress)
        db.session.commit()

        return jsonify({'message': 'Book associated with user successfully', 'progress_id': new_progress.id}), 201

    except Exception as e:
        return jsonify({'error': str(e)}), 500
