from flask import Blueprint, request, jsonify
from werkzeug.security import generate_password_hash
from models import db, User

users_bp = Blueprint('main', __name__)


@users_bp.route('/users', methods=['POST'])
def create_user():
    data = request.get_json()

    hashed_password = generate_password_hash(data['password'], method='pbkdf2:sha256', salt_length=8)

    new_user = User(
        name=data['name'],
        email=data['email'],
        password=hashed_password,
        role=data['role']
    )

    db.session.add(new_user)
    db.session.commit()

    return jsonify({'message': 'User created!', 'id': new_user.id}), 201


@users_bp.route('/users', methods=['GET'])
def get_users():
    users = User.query.all()

    return jsonify([{
        'id': user.id,
        'name': user.name,
        'email': user.email,
        'role': user.role,
        'created_at': user.created_at,
        'updated_at': user.updated_at
    } for user in users])


@users_bp.route('/users/<int:id>', methods=['GET'])
def get_user(id):
    user = User.query.get_or_404(id)

    return jsonify({
        'id': user.id,
        'name': user.name,
        'email': user.email,
        'role': user.role,
        'created_at': user.created_at,
        'updated_at': user.updated_at
    })


@users_bp.route('/users/<int:id>', methods=['PUT'])
def update_user(id):
    data = request.get_json()
    user = User.query.get_or_404(id)

    user.name = data.get('name', user.name)
    user.email = data.get('email', user.email)

    if 'password' in data:
        user.password = generate_password_hash(data['password'], method='pbkdf2:sha256', salt_length=8)

    user.role = data.get('role', user.role)

    db.session.commit()
    return jsonify({'message': 'User updated!'})


@users_bp.route('/users/<int:id>', methods=['DELETE'])
def delete_user(id):
    user = User.query.get_or_404(id)
    db.session.delete(user)
    db.session.commit()

    return jsonify({'message': 'User deleted!'})
